# -*- coding: utf-8 -*-
from .speedcurve import SpeedCurve

__author__ = 'Matt Chung'
__copyright__ = 'Copyright 2014 Matt Chung'
__license__ = 'MIT'
__title__ = 'speedcurve'
__version__ = '0.1.0'

__all__ = (
    'SpeedCurve',
)
